@@ -17,6 +17,7 @@ from feedgen.entry import FeedEntry
 from feedgen.util import ensure_format
 import feedgen.version
 import sys
+from six import string_types
 
 
 _feedgen_version = feedgen.version.version_str
@@ -199,7 +200,7 @@ class FeedGenerator(object):
 		return feed, doc
 
 
-	def atom_str(self, pretty=False, extensions=True):
+	def atom_str(self, pretty=False, extensions=True, encoding="unicode"):
 		'''Generates an ATOM feed and returns the feed XML as string.
 
 		:param pretty: If the feed should be split into multiple lines and
@@ -209,10 +210,10 @@ class FeedGenerator(object):
 		:returns: String representation of the ATOM feed.
 		'''
 		feed, doc = self._create_atom(extensions=extensions)
-		return etree.tostring(feed, pretty_print=pretty)
+		return etree.tostring(feed, pretty_print=pretty, encoding=encoding)
 
 
-	def atom_file(self, filename, extensions=True, pretty=False):
+	def atom_file(self, filename, extensions=True, pretty=False, encoding="UTF-8"):
 		'''Generates an ATOM feed and write the resulting XML to a file.
 
 		:param filename: Name of file to write, or a file-like object, or a URL.
@@ -220,7 +221,7 @@ class FeedGenerator(object):
 			generation (default: enabled).
 		'''
 		feed, doc = self._create_atom(extensions=extensions)
-		doc.write(filename, pretty_print=pretty)
+		doc.write(filename, pretty_print=pretty, encoding=encoding)
 
 
 	def _create_rss(self, extensions=True):
@@ -360,7 +361,7 @@ class FeedGenerator(object):
 		return feed, doc
 
 
-	def rss_str(self, pretty=False, extensions=True):
+	def rss_str(self, pretty=False, extensions=True, encoding="unicode"):
 		'''Generates an RSS feed and returns the feed XML as string.
 
 		:param pretty: If the feed should be split into multiple lines and
@@ -370,10 +371,10 @@ class FeedGenerator(object):
 		:returns: String representation of the RSS feed.
 		'''
 		feed, doc = self._create_rss(extensions=extensions)
-		return etree.tostring(feed, pretty_print=pretty)
+		return etree.tostring(feed, pretty_print=pretty, encoding=encoding)
 
 
-	def rss_file(self, filename, extensions=True, pretty=False):
+	def rss_file(self, filename, extensions=True, pretty=False, encoding="UTF-8"):
 		'''Generates an RSS feed and write the resulting XML to a file.
 
 		:param filename: Name of file to write, or a file-like object, or a URL.
@@ -381,7 +382,7 @@ class FeedGenerator(object):
 			generation (default: enabled).
 		'''
 		feed, doc = self._create_rss(extensions=extensions)
-		doc.write(filename, pretty_print=pretty)
+		doc.write(filename, pretty_print=pretty, encoding=encoding)
 
 
 	def title(self, title=None):
@@ -431,7 +432,7 @@ class FeedGenerator(object):
 		:returns: Modification date as datetime.datetime
 		'''
 		if not updated is None:
-			if isinstance(updated, basestring):
+			if isinstance(updated, string_types):
 				updated = dateutil.parser.parse(updated)
 			if not isinstance(updated, datetime):
 				raise ValueError('Invalid datetime format')
@@ -670,9 +671,9 @@ class FeedGenerator(object):
 		'''
 		if not generator is None:
 			self.__atom_generator = {'value':generator}
-			if not version in None:
+			if not version is None:
 				self.__atom_generator['version'] = version
-			if not uri in None:
+			if not uri is None:
 				self.__atom_generator['uri'] = uri
 			self.__rss_generator = generator
 		return self.__atom_generator
@@ -846,7 +847,7 @@ class FeedGenerator(object):
 		:returns: Publication date as datetime.datetime
 		'''
 		if not pubDate is None:
-			if isinstance(pubDate, basestring):
+			if isinstance(pubDate, string_types):
 				pubDate = dateutil.parser.parse(pubDate)
 			if not isinstance(pubDate, datetime):
 				raise ValueError('Invalid datetime format')
